@@ -11,10 +11,11 @@
 
 #include "ui_svncheckoutdialog.h"
 
-class SvnCheckoutDialog : public QDialog {
+class SvnCheckoutDialog : public QDialog
+{
     Q_OBJECT
 public:
-    SvnCheckoutDialog(const QString& contextDir, QWidget *parent = nullptr);
+    SvnCheckoutDialog(const QString &contextDir, QWidget *parent = nullptr);
     virtual ~SvnCheckoutDialog() override;
 
 public Q_SLOTS:
@@ -22,13 +23,13 @@ public Q_SLOTS:
     void on_pbOk_clicked();
 
 Q_SIGNALS:
-    void infoMessage(const QString& msg);
-    void errorMessage(const QString& msg);
-    void operationCompletedMessage(const QString& msg);
+    void infoMessage(const QString &msg);
+    void errorMessage(const QString &msg);
+    void operationCompletedMessage(const QString &msg);
 
 private:
     Ui::SvnCheckoutDialog m_ui;
     QString m_dir;
 };
 
-#endif  // SVNCHECKOUTDIALOG_H
+#endif // SVNCHECKOUTDIALOG_H
